#
# Please do not update/rebuild/touch this package before asking first
# to KDE team.
# This package is part of the KDE Stack.
#

%define rel 7

Name:           heaptrack
Version: 1.5.0
Release:        %mkrel %{rel}
Summary:        A heap memory profiler for Linux
Group:          Graphical desktop/KDE
License:        GPLv2+
URL:            https://invent.kde.org/sdk/heaptrack
Source0:        https://download.kde.org/stable/heaptrack/%{version}/%{name}-%{version}.tar.xz
## Upstream patches
Patch1:         0001-Use-boost::hash_combine-to-prevent-collisions-in-tsl-pointermap.patch
Patch2:         0001-fix-appdata-url.patch
Patch3:         0001-Support-KChart6-for-KF6.patch
Patch4:         0001-Use-QString-for-KConfigGroup-names.patch
# https://invent.kde.org/sdk/heaptrack/-/commit/c6c45f3455a652c38aefa402aece5dafa492e8ab
# Will prolly be unneeded next release.
Patch5:         fix-gcc14-cmake-compat.patch

BuildRequires:  kf6-rpm-macros

BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)

BuildRequires:  cmake(KF6CoreAddons)
BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6ItemModels)
BuildRequires:  cmake(KF6ThreadWeaver)
BuildRequires:  cmake(KF6ConfigWidgets)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6IconThemes)

BuildRequires:  cmake(KChart6)

BuildRequires:  boost-devel
BuildRequires:  libdwarf-devel
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libsparsehash)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)


%description
Heaptrack traces all memory allocations and annotates these events with stack
traces.Dedicated analysis tools then allow you to interpret the heap memory
profile to:
- find hotspots that need to be optimized to reduce the memory footprint of your
  application
- find memory leaks, i.e. locations that allocate memory which is never
  deallocated
- find allocation hotspots, i.e. code locations that trigger a lot of memory
  allocation calls
- find temporary allocations, which are allocations that are directly followed
  by their deallocation

%files -f %{name}.lang
%doc README.md
%license LICENSES/*.txt
%{_kf6_bindir}/%{name}
%{_kf6_bindir}/%{name}_gui
%{_kf6_bindir}/%{name}_print
%{_kf6_libdir}/%{name}/
%{_kf6_applicationsdir}/org.kde.%{name}.desktop
%{_kf6_metainfodir}/org.kde.%{name}.appdata.xml
%{_kf6_iconsdir}/hicolor/*/apps/%{name}.png
%{_includedir}/%{name}_api.h

#--------------------------------------------------------------------

%prep
%autosetup -p1

%build
%cmake_kf6 -DHEAPTRACK_USE_QT6:BOOL=ON
%cmake_build

%install
%cmake_install

%find_lang %{name} --all-name


%changelog
* Sun Feb 09 2025 wally <wally> 1.5.0-7.mga10
+ Revision: 2146226
- rebuild for boost 1.87.0

* Fri Sep 13 2024 wally <wally> 1.5.0-6.mga10
+ Revision: 2095472
- rebuild for boost 1.86.0

* Wed Jun 19 2024 wally <wally> 1.5.0-5.mga10
+ Revision: 2075343
- rebuild for boost 1.85.0

* Sat May 11 2024 daviddavid <daviddavid> 1.5.0-4.mga10
+ Revision: 2063588
- fix build failing on GCC14

* Sun Jan 14 2024 daviddavid <daviddavid> 1.5.0-3.mga10
+ Revision: 2031149
- add another upstream fix to use QString for KConfigGroup names
- backport some upstream fixes
- switch to KChart6
+ wally <wally>
- rebuild for boost 1.84.0

* Fri Nov 24 2023 daviddavid <daviddavid> 1.5.0-2.mga10
+ Revision: 2009479
- switch to Qt6/KF6

* Mon Oct 02 2023 daviddavid <daviddavid> 1.5.0-1.mga10
+ Revision: 1993106
- new version: 1.5.0

* Wed Sep 27 2023 wally <wally> 1.4.0-3.mga10
+ Revision: 1991447
- rebuild for boost 1.83.0

* Sun Dec 25 2022 wally <wally> 1.4.0-2.mga9
+ Revision: 1926780
- rebuild for boost 1.81.0

* Sun Sep 04 2022 papoteur <papoteur> 1.4.0-1.mga9
+ Revision: 1883753
- new 1.4.0

* Sun Jul 03 2022 wally <wally> 1.3.0-3.mga9
+ Revision: 1867258
- rebuild for boost 1.79.0

* Wed Apr 06 2022 umeabot <umeabot> 1.3.0-2.mga9
+ Revision: 1846039
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 1.3.0-1.mga9
+ Revision: 1762787
- new version 1.3.0
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.2.0-6.mga9
+ Revision: 1744719
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.2.0-5.mga9
+ Revision: 1722969
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.2.0-4.mga8
+ Revision: 1666767
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.2.0-3.mga8
+ Revision: 1662009
- rebuild for boost 1.74.0

* Wed Dec 16 2020 umeabot <umeabot> 1.2.0-2.mga8
+ Revision: 1658552
- Rebuild for new Qt5

* Tue Sep 01 2020 daviddavid <daviddavid> 1.2.0-1.mga8
+ Revision: 1620604
- new version: 1.2.0

* Thu May 28 2020 daviddavid <daviddavid> 1.1.0-10.mga8
+ Revision: 1588465
- switch appdata file to kf5_metainfo dir

* Sun May 03 2020 wally <wally> 1.1.0-9.mga8
+ Revision: 1578063
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1.1.0-8.mga8
+ Revision: 1544755
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.1.0-7.mga8
+ Revision: 1483380
- rebuild for boost 1.72.0
- build with new cmake macros

* Sat Mar 30 2019 umeabot <umeabot> 1.1.0-6.mga7
+ Revision: 1381897
- Qt5 Rebuild

* Tue Oct 16 2018 wally <wally> 1.1.0-5.mga7
+ Revision: 1321044
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1.1.0-4.mga7
+ Revision: 1298178
- Mageia 7 Mass Rebuild

* Tue May 29 2018 daviddavid <daviddavid> 1.1.0-3.mga7
+ Revision: 1232942
- new version: 1.1.0

* Mon Dec 25 2017 wally <wally> 1.0.0-4.mga7
+ Revision: 1184750
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 1.0.0-3.mga7
+ Revision: 1178326
- rebuild for boost 1.65

* Wed Sep 20 2017 daviddavid <daviddavid> 1.0.0-2.mga7
+ Revision: 1156009
- rebuild for new boost 1.64.0

* Sun Jul 23 2017 daviddavid <daviddavid> 1.0.0-1.mga7
+ Revision: 1129507
- initial package heaptrack

